pilas.actores

Package pilas :: Package actores |
[hide private]
[frames] | no frames]

# Package actores

source code

# Módulo pilas.actores

El módulo actores contiene una serie de clases para representar personajes de videojuegos.

Para crear actores en una escena del juego simplemente se tiene que crear un nuevo objeto a partir de una clase.

Por ejemplo, para crear un pongüino podríamos escribir la siguiente sentencia:

    >>> p = pilas.actores.Pingu()

Submodules | [hide private]
pilas.actores.aceituna pilas.actores.actor pilas.actores.animacion pilas.actores.animado pilas.actores.banana pilas.actores.bomba pilas.actores.boton pilas.actores.caja pilas.actores.cooperativista pilas.actores.cursordisparo pilas.actores.dialogo pilas.actores.ejes pilas.actores.energia pilas.actores.estrella pilas.actores.explosion pilas.actores.fantasma pilas.actores.globo pilas.actores.globoelegir pilas.actores.humo pilas.actores.mano pilas.actores.mapa pilas.actores.mapatiled pilas.actores.martian pilas.actores.menu pilas.actores.moneda pilas.actores.mono pilas.actores.nave pilas.actores.navekids pilas.actores.opcion pilas.actores.ovni pilas.actores.pacman pilas.actores.pausa pilas.actores.pelota pilas.actores.personajes_rpg pilas.actores.piedra pilas.actores.pingu pilas.actores.pizarra pilas.actores.proyectil pilas.actores.puntaje pilas.actores.sonido pilas.actores.temporizador pilas.actores.texto pilas.actores.texto_inferior pilas.actores.torreta pilas.actores.tortuga pilas.actores.utils pilas.actores.zanahoria

Variables | [hide private]
| todos = ``[``]``
| __doc__ = ``...``
| __package__ = ``'``pilas.actores``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      M\xc3\xb3dulo pilas.actores
      ====================

      El m\xc3\xb3dulo actores contiene una serie de clases
      para representar personajes de videojuegos.

      Para crear actores en una escena del juego simplemente
      ...